@@ -1,21 +1,19 @@
-# coding:utf-8
-u"""Модуль, реализущий работу с контекстом выполнения операции."""
-from __future__ import absolute_import
-
-from decimal import Decimal
-from logging import getLogger
+#coding:utf-8
+'''
+Модуль, реализущий работу с контекстом выполнения операции
+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+'''
+#author: akvarats
 import datetime
 import json
+from decimal import Decimal
 
-from django.utils.encoding import force_text
-from m3_django_compat import get_request_params
-from six import iteritems
-from six import python_2_unicode_compatible
-from six import string_types
-from six import text_type
-
-
-logger = getLogger('django')
+from django.utils.encoding import force_unicode
+try:
+    from django.utils.log import logger
+except ImportError:
+    from django.utils.log import getLogger
+    logger = getLogger('django')
 
 
 def _date2str(*args):
@@ -23,8 +21,7 @@ def _date2str(*args):
     from m3 import date2str
     return date2str(*args)
 
-
-# ============================= ИСКЛЮЧЕНИЯ ====================================
+#============================= ИСКЛЮЧЕНИЯ =====================================
 class ActionContextException(Exception):
     """ Базовый класс для исключений контекста """
     pass
@@ -57,7 +54,6 @@ class ConversionFailed(ActionContextException):
             self.value, self.type)
 
 
-@python_2_unicode_compatible
 class ContextBuildingError(ActionContextException):
     u"""
     Ошибка построения контекста
@@ -86,7 +82,7 @@ class ContextBuildingError(ActionContextException):
 
     __str__ = __repr__
 
-    def __str__(self):
+    def __unicode__(self):
         log = []
         for title, data in (
             (u"Отсутствуют обязательные параметры:", self.requiremets),
@@ -105,7 +101,7 @@ class CriticalContextBuildingError(ContextBuildingError):
     pass
 
 
-# ================================== ПАРСЕРЫ ==================================
+#================================== ПАРСЕРЫ ===================================
 def _make_datetime_parser(extractor, formats):
     def parse(value):
         for (fmt, length) in formats:
@@ -155,7 +151,7 @@ _datetime_parser = _make_datetime_parser(lambda x: x, formats=(
     ('%d.%m.%Y', 10),
     ('%H:%M:%S', 8),
     ('%H:%M', 5),
-))
+)),
 
 
 _date_parser = _make_datetime_parser(
@@ -176,8 +172,8 @@ _time_parser = _make_datetime_parser(
 
 
 _PARSERS = {
-    str: _make_simple_parser(text_type),  # Иду на поводу у хомячков (FIXME)
-    text_type: _make_simple_parser(text_type),
+    str: _make_simple_parser(unicode),  # Иду на поводу у хомячков (FIXME)
+    unicode: _make_simple_parser(unicode),
     int: _make_simple_parser(int),
     float: _make_simple_parser(float),
     Decimal: _make_simple_parser(Decimal),
@@ -212,12 +208,7 @@ _PARSERS = {
 }
 
 
-# ================================== КЛАССЫ ===================================
-
-# "Стражник" для значения по умолчанию ActionContextDeclaration.
-_none = object()
-
-
+#================================== КЛАССЫ ====================================
 class ActionContextDeclaration(object):
     u"""
     Класс, который определяет правило извлечения параметра из
@@ -236,7 +227,7 @@ class ActionContextDeclaration(object):
         необходимо для сообщений об ошибках
     """
     def __init__(
-            self, name='', default=_none, type=None,
+            self, name='', default=None, type=None,
             required=False, verbose_name='', *args, **kwargs):
         assert type, 'type must be defined!'
         self.name = name
@@ -293,7 +284,7 @@ class ActionContext(object):
                     for e in elements
                 ]
             else:
-                if arg_type not in _PARSERS:
+                if not arg_type in _PARSERS:
                     raise TypeError('Unknown parser "%r"!' % arg_type)
                 value = _PARSERS[arg_type](raw_value)
         except AssertionError:
@@ -323,7 +314,8 @@ class ActionContext(object):
         key = value = ptype = None
         try:
             # переносим параметры в контекст из запроса
-            for key, value in iteritems(get_request_params(request)):
+            for key in request.REQUEST:
+                value = request.REQUEST[key]
                 # Пустые параметры не конвертируем,
                 # т.к. они могут вызвать ошибку
                 if not value:
@@ -339,7 +331,7 @@ class ActionContext(object):
         except IOError as err:
             # В некоторых браузерах (предполагается что в ie)
             # происходит следующие:
-            # REQUEST читается и в какой-то момент связь прекращается
+            # request.REQUEST читается и в какой-то момент связь прекращается
             # из-за того, что браузер разрывает соединение,
             # в следствии этого происходит ошибка
             # IOError: request data read error
@@ -355,7 +347,7 @@ class ActionContext(object):
 
         # переносим обязательные параметры, которые не встретились в запросе
         for rule in rules if rules else []:
-            if rule.required and rule.default is not _none and (
+            if rule.required and rule.default is not None and (
                     not params[rule.name][1]):
                 # если параметр не передан в запросе, но
                 # он является обязательным и задано значение по умолчанию,
@@ -376,7 +368,7 @@ class ActionContext(object):
         if not rules:
             return
         for rule in rules:
-            if rule.required and getattr(self, rule.name, _none) is _none:
+            if rule.required and getattr(self, rule.name, None) is None:
                 raise ActionContext.RequiredFailed(rule.human_name())
 
     def json(self):
@@ -392,7 +384,7 @@ class ActionContext(object):
             elif isinstance(obj, datetime.time):
                 result = _date2str(obj, '%H:%M')
             else:
-                result = force_text(obj)
+                result = force_unicode(obj)
 
             return result
 
@@ -400,7 +392,7 @@ class ActionContext(object):
         # и при этом только те, которые не callable
         data = dict(
             (k, v)
-            for k, v in iteritems(self.__dict__)
+            for k, v in self.__dict__.iteritems()
             if not (
                 k.startswith('_') or
                 callable(v)
@@ -426,7 +418,7 @@ class ActionContext(object):
         return result
 
 
-# -----------------------------------------------------------------------------
+#-----------------------------------------------------------------------------
 class DeclarativeActionContext(ActionContext):
     """
     ActionContext, использующий декларативное описание контекста
@@ -448,8 +440,24 @@ class DeclarativeActionContext(ActionContext):
         'int': int,
         'float': float,
         'str': str,
-        'unicode': text_type,
+        'unicode': unicode,
         'decimal': Decimal,
+
+        # >>> int_or_zero('')
+        # 0
+        # >>> int_or_zero('10')
+        # 10
+        'int_or_zero': lambda raw_str: 0 if not raw_str else int(raw_str),
+
+        # >>> int_or_none('')
+        # None
+        # >>> int_or_none('10')
+        # 10
+        'int_or_none': lambda raw_str: None if not raw_str else int(raw_str),
+
+        # >>> int_list('10,20, 30')
+        # [10, 20, 30]
+        'int_list': lambda raw_str: [int(i.strip()) for i in raw_str.split(',')],
     }
 
     _mode = None
@@ -473,7 +481,7 @@ class DeclarativeActionContext(ActionContext):
         # определяем режим, если правилла описаны парой
         if isinstance(rules, tuple):
             # режим
-            mode = get_request_params(request).get(rules[0])
+            mode = request.REQUEST.get(rules[0])
             try:
                 # правила для конкретного режима
                 rules = rules[1][mode]
@@ -487,7 +495,7 @@ class DeclarativeActionContext(ActionContext):
         errors = []
         only_noncritical = True
 
-        for key, parser_data in iteritems(rules):
+        for key, parser_data in rules.iteritems():
             parser = parser_data['type']
             if not callable(parser):
                 try:
@@ -500,7 +508,7 @@ class DeclarativeActionContext(ActionContext):
 
             add_error_to = None
             try:
-                val = get_request_params(request).get(key)
+                val = request.REQUEST.get(key)
                 if val is None:
                     if 'default' in parser_data:
                         val = parser_data['default']
@@ -557,5 +565,5 @@ class DeclarativeActionContext(ActionContext):
         return isinstance(data, dict) or (
             isinstance(data, tuple) and
             len(data) == 2 and
-            isinstance(data[0], string_types)
+            isinstance(data[0], basestring)
         )
